{% load static %}

<script
    src="{% static 'timezones/libs/moment-timezone/0.5.36/moment-timezone-with-data-1970-2030.min.js' %}"
    integrity="sha512-HdWVl8NTC8n0bl0Ypuw1baRuZvO4bUcnGWhLTiI9yiisXzHbgKxlrmf2AMaa3yaXsi8GVzwonsASxsLs7ffAFw=="
    crossorigin="anonymous"
></script>
