{% load static %}

<script
    src="{% static 'timezones/libs/jquery-timeago/1.6.7/jquery.timeago.min.js' %}"
    integrity="sha512-Fa5vf0oXzZKvD2EWgLQaebZ7X+7IMDAbdCvOjEivYkFLc830J6x7jYy7N9g+Rz0rVx4UZA7xSUboc14jSrsKVA=="
    crossorigin="anonymous"
></script>
