{% load timezones %}

<script
    src="{% timezones_static 'timezones/js/timezones.min.js' %}"
    integrity="sha512-p/T1Wmq0lWiYMNBbODA7yXFsFtCzugX8mEsh9Z9S8rlMP3sx6GRvP3q4mhjnnk3Y8h76HaGcKh6kJzV1QW/ZmA=="
    crossorigin="anonymous"
></script>
