{% load timezones %}

<link
    rel="stylesheet"
    href="{% timezones_static 'timezones/css/timezones.min.css' %}"
    integrity="sha512-8lYk4QlNTYSaxTlTWH4Z6Qslhf+NrgoxzD78IzMN+//b9WwMdQWzFWWrqX5dl7z/jQHU1hg38fYrm2F0+1KVEg=="
    crossorigin="anonymous"
>
