{% extends 'allianceauth/base-bs5.html' %}

{% load i18n %}

{% block page_title %}
    {% translate "Time Zones" %}
{% endblock %}

{% block header_nav_brand %}
    {% translate "Time Zones" %}
{% endblock header_nav_brand %}

{% block content %}
    <div class="aa-timezones">
        {% if not user.is_authenticated %}
            <div class="aa-timezones-header">
                {% translate "Time Zones" as page_header %}
                {% include "framework/header/page-header.html" with title=page_header %}
            </div>
        {% endif %}

        <div class="aa-timezones-body">
            {% block aa_timezones_body %}{% endblock %}
        </div>

        <div class="aa-timezones-footer mt-3 pt-3 border-top border-light">
            {% include "timezones/partials/footer/app-translation-footer.html" %}
        </div>
    </div>
{% endblock %}
